% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/extendr-wrappers.R
\name{segment_worker}
\alias{segment_worker}
\title{Segment text with an internal native worker.}
\usage{
segment_worker(text, worker)
}
\arguments{
\item{text}{Character scalar containing the input text.}

\item{worker}{A native \code{JiebaWorker} handle created by the internal worker
constructor.}
}
\value{
A character vector of segmented tokens.
}
\description{
Internal bridge used by \code{segment()} to segment a single UTF-8 string.
}
\keyword{internal}
